==> bonita-server-6.1.0-sources.jar: org/bonitasoft/engine/identity/model/builder/SContactInfoUpdateBuilder.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.identity.model.builder;

/**
 * @author Emmanuel Duchastenier
 */
public interface SContactInfoUpdateBuilder extends UpdateBuilder {

    SContactInfoUpdateBuilder updateEmail(final String email);

    SContactInfoUpdateBuilder updatePhoneNumber(final String phoneNumber);

    SContactInfoUpdateBuilder updateMobileNumber(final String mobileNumber);

    SContactInfoUpdateBuilder updateFaxNumber(final String faxNumber);

    SContactInfoUpdateBuilder updateBuilding(final String building);

    SContactInfoUpdateBuilder updateRoom(final String room);

    SContactInfoUpdateBuilder updateAddress(final String address);

    SContactInfoUpdateBuilder updateZipCode(final String zipCode);

    SContactInfoUpdateBuilder updateCity(final String city);

    SContactInfoUpdateBuilder updateState(final String state);

    SContactInfoUpdateBuilder updateCountry(final String country);

    SContactInfoUpdateBuilder updateWebsite(final String website);

}

==> bonita-server-6.5.3-sources.jar: org/bonitasoft/engine/identity/model/builder/SContactInfoUpdateBuilder.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.identity.model.builder;

/**
 * @author Emmanuel Duchastenier
 */
public interface SContactInfoUpdateBuilder extends SIdentityUpdateBuilder {

    SContactInfoUpdateBuilder updateEmail(final String email);

    SContactInfoUpdateBuilder updatePhoneNumber(final String phoneNumber);

    SContactInfoUpdateBuilder updateMobileNumber(final String mobileNumber);

    SContactInfoUpdateBuilder updateFaxNumber(final String faxNumber);

    SContactInfoUpdateBuilder updateBuilding(final String building);

    SContactInfoUpdateBuilder updateRoom(final String room);

    SContactInfoUpdateBuilder updateAddress(final String address);

    SContactInfoUpdateBuilder updateZipCode(final String zipCode);

    SContactInfoUpdateBuilder updateCity(final String city);

    SContactInfoUpdateBuilder updateState(final String state);

    SContactInfoUpdateBuilder updateCountry(final String country);

    SContactInfoUpdateBuilder updateWebsite(final String website);

}
